@@ -49,6 +49,10 @@ type encoder
 (** Create a new lame encoder. *)
 val create_encoder : unit -> encoder
 
+(** Frame size. All audio frames submitted to the encoder
+  * should have this number of samples per channel. *)
+val frame_size : encoder -> int
+
 (** {2 Parameters} *)
 
 (** Input sample rate in Hz (default: 44100). *)
@@ -77,6 +81,9 @@ val set_out_samplerate : encoder -> int -> unit
   *)
 val set_quality : encoder -> int -> unit
 
+(* Enable/disable the bit reservoir. *)
+val set_disable_reservoir : encoder -> bool -> unit
+
 (** Compression mode. *)
 type mode =
   | Stereo  (** stereo, channels encoded independely *)
@@ -95,7 +102,8 @@ type vbr_mode =
   | Vbr_mtrh
   | Vbr_max_indicator
 
-(* don't use this (it's for sanity checks) *)
+(** Write a Xing VBR header frame. (default: {true}) *)
+val set_bWriteVbrTag : encoder -> bool -> unit
 
 (** Set the VBR mode. *)
 val set_vbr_mode : encoder -> vbr_mode -> unit
